Example task file, to download, cleanup, merge and save a new xmltv file.


```
pipx install fhs_xmltv_tools

fhs-xmltv-tools run-tasks --yaml-command tasks_example.yml

or for more options

fhs-xmltv-tools --help
```

